@@ -52,6 +52,18 @@ sub new {
 ## Import
 package DDC::Any;
 
+##--------------------------------------------------------------
+## $bool = PACKAGE->have_xs()
+##  + attempts to load DDC::XS, and returns true if it is available in a suitable version
+our $MIN_XS_VERSION = 0.15;
+sub have_xs {
+  shift if (UNIVERSAL::isa($_[0],__PACKAGE__));
+  eval "use DDC::XS;" if (!$INC{'DDC/XS.pm'});
+  return 0 if (!$INC{'DDC/XS.pm'});
+  (my $xs_version = ($DDC::XS::VERSION||0)) =~ s/[^0-9\.]//g;
+  return ($xs_version && $xs_version >= $MIN_XS_VERSION);
+}
+
 ##--------------------------------------------------------------
 ## \%dst_stash = mapstash($src,$dst,%opts)
 ##  + %opts:
@@ -119,8 +131,7 @@ sub import {
 
   ##-- load back-end
   if (!$which || $which eq 'xs') {
-    eval "use DDC::XS;" if (!$INC{'DDC/XS.pm'});
-    if (!$INC{'DDC/XS.pm'}) {
+    if (!$that->have_xs()) {
       die("DDC::Any::import(): failed to load DDC::XS back-end: $@") if (($which||'') eq 'xs');
     } else {
       $which = 'DDC::XS';
