@@ -71,7 +71,7 @@ sub Descendants {
     next if (exists $visited{$obj});
     push(@kids,$obj);
     $visited{$obj} = undef;
-    foreach ($obj->Children) {
+    foreach (@{$obj->Children}) {
       push(@stack,$_);
     }
   }
